@@ -5,7 +5,7 @@ use warnings;
 
 our ($VERSION, $AUTOLOAD);
 
-$VERSION = '1.04';
+$VERSION = '1.07';
 
 sub __new
 {
@@ -24,27 +24,26 @@ sub __new
     $obj->{helpers}         = \%{"${class}::data_helpers"};
     $obj->{duration}        = \%{"${class}::data_duration"};
     $obj->{aliases}         = \%{"${class}::data_aliases"};
+    $obj->{rewrite}         = \%{"${class}::data_rewrite"};
 
-    return bless $obj, ref($class) || $class;
+    return bless $obj, $class;
 }
 
 AUTOLOAD
 {
     my ($self, $exp) = @_;
 
-    my ($caller) = $AUTOLOAD =~ /(.*)::.*/;
-    my $sub = $AUTOLOAD;
-    $sub =~ s/^.*:://;
+    my ($caller, $sub) = $AUTOLOAD =~ /^(.*)::(.*)$/;
 
     if (substr($sub, 0, 2) eq '__') {
-       $sub =~ s/^__//;
-       no strict 'refs';
-       if (defined $exp && length $exp) {
-           return ${$caller.'::'.$sub}{$exp};
-       }
-       else {
-           return \%{$caller.'::'.$sub};
-       }
+        $sub =~ s/^__//;
+        no strict 'refs';
+        if (defined $exp && length $exp) {
+            return ${$caller.'::'.$sub}{$exp};
+        }
+        else {
+            return \%{$caller.'::'.$sub};
+        }
     }
 }
 
